body {
    font-size: 95%;
    font-family: 'Open Sans', sans-serif;
}

tt, code, pre, .type {
    font-family: andale mono, courier new, courier, monospace;
    font-size: 90%;
}

pre {
    color: #0000aa;
}

ul li p {
    margin: 0;
    padding: 0;
}

/* Based on http://phrogz.net/CSS/columns3.html */
div.toc {
    float: left;
    margin: 0;
    padding: 0;
    padding-top: 0.5em;
    border: 0;
    width: 16em;

    background-color: #f9f9f9;
    margin-right:1em;
}

div.content {
    margin: 0;
    padding: 0;

    /* won't match if font is smaller in toc */
    border-left: 16em solid #f9f9f9;
    padding-left: 1em;
}

div.content:after {
    content:' ';
    clear:both;
    display:block;
    height:0;
    overflow:hidden
}

div.footer {
    clear:left;
    padding: 0.5em;
    /* background-color: #f9f9f9;
    border: 1px solid #aaaaaa; */
    font-size: 80%;
    margin: 0;
}

div.toc ul {
    list-style: none;
    padding: 0;
    margin: 0;
}

div.toc li ul a, li ul span.currentlink
{
    font-weight: normal;
    font-size: 90%;
    padding-left: 2em;
}

div.toc a, span.currentlink{
    display:block;
    text-decoration: none;
    padding-left: 0.5em;
    color: #0000aa;
}

span.currentlink {
    text-decoration: none;
    background-color: #aaaaf9;
}

div.toc a:visited {
    color: #0000aa;
}

div.toc a:hover {
    background-color: #f9f9aa;
}

.programlisting, .screen {
    margin: 0;
    border: 1px solid #aaaaaa;
    background-color: #f9f9f9;
    padding: 0.17em;
    margin: 1em;
    margin-right: 3em;
}

.parameter {
    font-style: italic;
}

h1, h2 {
    padding-top: 0.5em;
    padding-bottom: 0.17em;
    margin: 0;
    font-weight: normal;
    color: black;
    border-bottom: 1px solid #aaaaaa;
}

h1 {
    font-size: 188%;
}

div.chapter h2 {
    font-size: 188%;
}

div.section h2 {
    font-size: 150%;
}
